@@ -6,7 +6,7 @@ from os.path import join as __path_join
 from multiprocessing import Process
 
 __name_module__ = 'py-web-server-flask-Orinnass'
-__version__ = '1.0.4'
+__version__ = '1.1.0'
 __web_server__ = __Flask(__name__)
 
 __config = Configuration()
@@ -14,6 +14,7 @@ __host_address = __config.web_server['address']
 __port = __config.web_server['port']
 __enabled = __config.web_server['enabled']
 __api_directory = __config.web_server.get('api_directory')
+__start_in_other_process = __config.web_server["start_in_other_process"]
 __logger = __config.logging.get_logger(__name__)
 del __config
 
@@ -67,7 +68,9 @@ def __get_version():
     return __Response(__version__, mimetype='application/text')
 
 
-def start_server() -> Process:
-    web_process = Process(target=__start_web_server, daemon=True)
-    web_process.start()
-    return web_process
+def start_server():
+    if __start_in_other_process:
+        web_process = Process(target=__start_web_server, daemon=True)
+        web_process.start()
+        return web_process
+    __start_web_server()
